 # minuteinbox

[![Version](https://img.shields.io/pypi/v/minuteinbox?logo=pypi)](https://pypi.org/project/minuteinbox)
[![Quality Gate Status](https://img.shields.io/sonar/alert_status/fedecalendino_minuteinbox?logo=sonarcloud&server=https://sonarcloud.io)](https://sonarcloud.io/dashboard?id=fedecalendino_minuteinbox)
[![CodeCoverage](https://img.shields.io/sonar/coverage/fedecalendino_minuteinbox?logo=sonarcloud&server=https://sonarcloud.io)](https://sonarcloud.io/dashboard?id=fedecalendino_minuteinbox)

Unofficial python wrapper for minuteinbox.com
